@@ -9,6 +9,7 @@ from traceback import print_exc
 from time import time
 from typing import ItemsView, Iterator, KeysView, ValuesView
 from .utils import support_pillow, can_load, load_file, tag_redraw
+from .formats import unsupported_formats
 
 WARNINGS = True
 
@@ -18,16 +19,28 @@ class ImagePreviewCollection:
 
     def __init__(self, max_size: tuple = (128, 128), lazy_load: bool = True):
         '''Create collection and start internal timer.'''
-        if WARNINGS and not support_pillow():
-            print('Pillow is not installed, therefore:')
-            print('-   BIP images load without scaling.')
+        if WARNINGS:
+            if not support_pillow():
+                print('Pillow is not installed, therefore:')
+                print('- BIP images load without scaling.')
 
-            if lazy_load:
-                print('-   Other images load slowly (Blender standard).')
-            if lazy_load and max_size != (128, 128):
-                print('-   Other images load in 128x128 (Blender standard).')
-            elif not lazy_load and max_size != (256, 256):
-                print('-   Other images load in 256x256 (Blender standard).')
+                if lazy_load:
+                    print('- Other images load slowly (Blender standard).')
+                if lazy_load and max_size != (128, 128):
+                    print('- Other images load in 128x128 (Blender standard).')
+                elif not lazy_load and max_size != (256, 256):
+                    print('- Other images load in 256x256 (Blender standard).')
+
+            else:
+                unsupported = unsupported_formats()
+                if unsupported:
+                    print('Pillow is installed, but:')
+
+                    for name in unsupported:
+                        print(
+                            f'- {name} images are not supported by Pillow',
+                            'and load slowly (Blender standard).',
+                        )
 
         self._collection = bpy.utils.previews.new()
         self._max_size = max_size
@@ -39,7 +52,7 @@ class ImagePreviewCollection:
             self._queue = Queue()
 
             if not bpy.app.timers.is_registered(self._timer):
-                bpy.app.timers.register(self._timer)
+                bpy.app.timers.register(self._timer, persistent=True)
 
     def __len__(self) -> int:
         '''Return the amount of previews in the collection.'''
